@@ -1,5 +1,5 @@
 macro_rules! aws_sdk_macro {
-    (feature = $feature:literal, crate_name = $mod_name:ident, aws_version = $version:literal,) => {
+    (feature = $feature:literal, crate_name = $crate_name:ident, mod_name = $mod_name:ident, aws_version = $version:literal,) => {
         #[cfg(feature = $feature)]
         #[cfg_attr(docsrs, doc(cfg(feature = $feature)))]
         pub mod $mod_name {
@@ -21,7 +21,7 @@ macro_rules! aws_sdk_macro {
             //! Items received from a [aws-sdk-dynamodb] call can be run through [`from_items`].
             //!
             //! ```
-            #![doc = concat!("# use ", stringify!($mod_name), "::client::Client;")]
+            #![doc = concat!("# use ", stringify!($crate_name), "::client::Client;")]
             //! # use serde_derive::{Serialize, Deserialize};
             //! # use serde_dynamo::from_items;
             //! #
@@ -48,7 +48,7 @@ macro_rules! aws_sdk_macro {
             //! Alternatively, to deserialize one item at a time, [`from_item`] can be used.
             //!
             //! ```
-            #![doc = concat!("# use ", stringify!($mod_name), "::client::Client;")]
+            #![doc = concat!("# use ", stringify!($crate_name), "::client::Client;")]
             //! # use serde_derive::{Serialize, Deserialize};
             //! # use serde_dynamo::from_item;
             //! #
@@ -79,7 +79,7 @@ macro_rules! aws_sdk_macro {
             //! it.
             //!
             //! ```
-            #![doc = concat!("# use ", stringify!($mod_name), "::client::Client;")]
+            #![doc = concat!("# use ", stringify!($crate_name), "::client::Client;")]
             //! # use serde_derive::{Serialize, Deserialize};
             //! # use serde_dynamo::to_item;
             //! #
@@ -98,7 +98,7 @@ macro_rules! aws_sdk_macro {
             //!     age: 42,
             //! };
             //!
-            //! // Turn it into an item that rusoto understands
+            //! // Turn it into an item that aws-sdk-dynamodb understands
             //! let item = to_item(user)?;
             //!
             //! // And write it!
@@ -116,7 +116,7 @@ macro_rules! aws_sdk_macro {
             //!
             //! ```
             //! use serde_dynamo::to_attribute_value;
-            #![doc = concat!("# use ", stringify!($mod_name), "::client::Client;")]
+            #![doc = concat!("# use ", stringify!($crate_name), "::client::Client;")]
             //! # use std::collections::HashMap;
             //! #
             //! # async fn get(client: &Client) -> Result<(), Box<dyn std::error::Error>> {
@@ -139,7 +139,7 @@ macro_rules! aws_sdk_macro {
             //!
             //! ```
             //! use serde_dynamo::to_attribute_value;
-            #![doc = concat!("# use ", stringify!($mod_name), "::client::Client;")]
+            #![doc = concat!("# use ", stringify!($crate_name), "::client::Client;")]
             //! # use std::collections::HashMap;
             //! #
             //! # async fn query(client: &Client) -> Result<(), Box<dyn std::error::Error>> {
@@ -169,249 +169,49 @@ macro_rules! aws_sdk_macro {
             //! [aws_sdk_dynamodb::model::AttributeValue]: https://docs.rs/rusoto_dynamodb/0.47.0/rusoto_dynamodb/struct.AttributeValue.html
 
             use crate::Result;
-            use ::$mod_name::model::AttributeValue;
-            use std::collections::HashMap;
+            use ::$crate_name::model::AttributeValue;
+            use ::$crate_name::types::Blob;
 
-            impl crate::AttributeValue for AttributeValue {
-                fn is_n(&self) -> bool {
-                    matches!(self, AttributeValue::N(..))
-                }
-
-                fn is_s(&self) -> bool {
-                    matches!(self, AttributeValue::S(..))
-                }
-
-                fn is_bool(&self) -> bool {
-                    matches!(self, AttributeValue::Bool(..))
-                }
-
-                fn is_b(&self) -> bool {
-                    matches!(self, AttributeValue::B(..))
-                }
-
-                fn is_null(&self) -> bool {
-                    matches!(self, AttributeValue::Null(..))
-                }
-
-                fn is_m(&self) -> bool {
-                    matches!(self, AttributeValue::M(..))
-                }
-
-                fn is_l(&self) -> bool {
-                    matches!(self, AttributeValue::L(..))
-                }
-
-                fn is_ss(&self) -> bool {
-                    matches!(self, AttributeValue::Ss(..))
-                }
-
-                fn is_ns(&self) -> bool {
-                    matches!(self, AttributeValue::Ns(..))
-                }
-
-                fn is_bs(&self) -> bool {
-                    matches!(self, AttributeValue::Bs(..))
-                }
-
-                fn as_n(&self) -> Option<&str> {
-                    if let AttributeValue::N(ref v) = self {
-                        Some(v)
-                    } else {
-                        None
+            impl From<crate::AttributeValue> for AttributeValue {
+                fn from(attribute_value: crate::AttributeValue) -> AttributeValue {
+                    match attribute_value {
+                        crate::AttributeValue::N(n) => AttributeValue::N(n),
+                        crate::AttributeValue::S(s) => AttributeValue::S(s),
+                        crate::AttributeValue::Bool(b) => AttributeValue::Bool(b),
+                        crate::AttributeValue::B(v) => AttributeValue::B(Blob::new(v)),
+                        crate::AttributeValue::Null(null) => AttributeValue::Null(null),
+                        crate::AttributeValue::M(m) => AttributeValue::M(m.into_iter().map(|(key, attribute_value)| (key, AttributeValue::from(attribute_value))).collect()),
+                        crate::AttributeValue::L(l) => AttributeValue::L(l.into_iter().map(AttributeValue::from).collect()),
+                        crate::AttributeValue::Ss(ss) => AttributeValue::Ss(ss),
+                        crate::AttributeValue::Ns(ns) => AttributeValue::Ns(ns),
+                        crate::AttributeValue::Bs(bs) => AttributeValue::Bs(bs.into_iter().map(Blob::new).collect()),
                     }
                 }
-
-                fn as_s(&self) -> Option<&str> {
-                    if let AttributeValue::S(ref v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_bool(&self) -> Option<bool> {
-                    if let AttributeValue::Bool(v) = self {
-                        Some(*v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_b(&self) -> Option<&[u8]> {
-                    if let AttributeValue::B(ref v) = self {
-                        Some(v.as_ref())
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_null(&self) -> Option<bool> {
-                    if let AttributeValue::Null(v) = self {
-                        Some(*v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_m(&self) -> Option<&HashMap<String, Self>> {
-                    if let AttributeValue::M(ref v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_l(&self) -> Option<&[Self]> {
-                    if let AttributeValue::L(ref v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_ss(&self) -> Option<&[String]> {
-                    if let AttributeValue::Ss(ref v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn as_ns(&self) -> Option<&[String]> {
-                    if let AttributeValue::Ns(ref v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_n(self) -> Option<String> {
-                    if let AttributeValue::N(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_s(self) -> Option<String> {
-                    if let AttributeValue::S(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_bool(self) -> Option<bool> {
-                    if let AttributeValue::Bool(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_b(self) -> Option<Vec<u8>> {
-                    if let AttributeValue::B(v) = self {
-                        Some(v.into_inner())
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_null(self) -> Option<bool> {
-                    if let AttributeValue::Null(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_m(self) -> Option<HashMap<String, Self>> {
-                    if let AttributeValue::M(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_l(self) -> Option<Vec<Self>> {
-                    if let AttributeValue::L(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_ss(self) -> Option<Vec<String>> {
-                    if let AttributeValue::Ss(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_ns(self) -> Option<Vec<String>> {
-                    if let AttributeValue::Ns(v) = self {
-                        Some(v)
-                    } else {
-                        None
-                    }
-                }
-
-                fn into_bs(self) -> Option<Vec<Vec<u8>>> {
-                    if let AttributeValue::Bs(v) = self {
-                        Some(v.into_iter().map(|b| b.into_inner()).collect())
-                    } else {
-                        None
-                    }
-                }
-
-                fn construct_n(input: String) -> Self {
-                    AttributeValue::N(input)
-                }
-
-                fn construct_s(input: String) -> Self {
-                    AttributeValue::S(input)
-                }
-
-                fn construct_bool(input: bool) -> Self {
-                    AttributeValue::Bool(input)
-                }
-
-                fn construct_b(input: &[u8]) -> Self {
-                    AttributeValue::B($mod_name::types::Blob::new(input))
-                }
-
-                fn construct_null(input: bool) -> Self {
-                    AttributeValue::Null(input)
-                }
-
-                fn construct_m(input: HashMap<String, Self>) -> Self {
-                    AttributeValue::M(input)
-                }
-
-                fn construct_l(input: Vec<Self>) -> Self {
-                    AttributeValue::L(input)
-                }
-
-                fn construct_ss(input: Vec<String>) -> Self {
-                    AttributeValue::Ss(input)
-                }
-
-                fn construct_ns(input: Vec<String>) -> Self {
-                    AttributeValue::Ns(input)
-                }
-
-                fn construct_bs(input: Vec<Vec<u8>>) -> Self {
-                    let input = input.into_iter().map($mod_name::types::Blob::new).collect();
-                    AttributeValue::Bs(input)
-                }
             }
 
-            /// A version of [`crate::to_attribute_value`] where the `Tout` generic is tied to
+            impl From<AttributeValue> for crate::AttributeValue {
+                fn from(attribute_value: AttributeValue) -> crate::AttributeValue {
+                    match attribute_value {
+                        AttributeValue::N(n) => crate::AttributeValue::N(n),
+                        AttributeValue::S(s) => crate::AttributeValue::S(s),
+                        AttributeValue::Bool(b) => crate::AttributeValue::Bool(b),
+                        AttributeValue::B(v) => crate::AttributeValue::B(v.into_inner()),
+                        AttributeValue::Null(null) => crate::AttributeValue::Null(null),
+                        AttributeValue::M(m) => crate::AttributeValue::M(m.into_iter().map(|(key, attribute_value)| (key, crate::AttributeValue::from(attribute_value))).collect()),
+                        AttributeValue::L(l) => crate::AttributeValue::L(l.into_iter().map(crate::AttributeValue::from).collect()),
+                        AttributeValue::Ss(ss) => crate::AttributeValue::Ss(ss),
+                        AttributeValue::Ns(ns) => crate::AttributeValue::Ns(ns),
+                        AttributeValue::Bs(bs) => crate::AttributeValue::Bs(bs.into_iter().map(Blob::into_inner).collect()),
+                        _ => panic!("Unexpectedly did not match any possible data types"),
+                    }
+                }
+            }
+
+            /// A version of [`crate::to_attribute_value`] where the `AV` generic is tied to
             /// [`aws-sdk-dynamodb::model::AttributeValue`](AttributeValue).
             ///
             /// Useful in very generic code where the type checker can't determine the type of
-            /// `Tout`.
+            /// `AV`.
             pub fn to_attribute_value<T>(value: T) -> Result<AttributeValue>
             where
                 T: serde::ser::Serialize,
@@ -419,11 +219,11 @@ macro_rules! aws_sdk_macro {
                 crate::ser::to_attribute_value(value)
             }
 
-            /// A version of [`crate::to_item`] where the `Tout` generic is tied to
+            /// A version of [`crate::to_item`] where the `AV` generic is tied to
             /// [`aws-sdk-dynamodb::model::AttributeValue`](AttributeValue).
             ///
             /// Useful in very generic code where the type checker can't determine the type of
-            /// `Tout`.
+            /// `AV`.
             pub fn to_item<T>(value: T) -> Result<std::collections::HashMap<String, AttributeValue>>
             where
                 T: serde::ser::Serialize,
@@ -431,11 +231,11 @@ macro_rules! aws_sdk_macro {
                 crate::ser::to_item(value)
             }
 
-            /// A version of [`crate::from_attribute_value`] where the `Tin` generic is tied to
+            /// A version of [`crate::from_attribute_value`] where the `AV` generic is tied to
             /// [`aws-sdk-dynamodb::model::AttributeValue`](AttributeValue).
             ///
             /// Useful in very generic code where the type checker can't determine the type of
-            /// `Tin`.
+            /// `AV`.
             pub fn from_attribute_value<'a, T>(attribute_value: AttributeValue) -> Result<T>
             where
                 T: serde::de::Deserialize<'a>,
@@ -443,11 +243,11 @@ macro_rules! aws_sdk_macro {
                 crate::de::from_attribute_value(attribute_value)
             }
 
-            /// A version of [`crate::from_item`] where the `Tin` generic is tied to
+            /// A version of [`crate::from_item`] where the `AV` generic is tied to
             /// [`aws-sdk-dynamodb::model::AttributeValue`](AttributeValue).
             ///
             /// Useful in very generic code where the type checker can't determine the type of
-            /// `Tin`.
+            /// `AV`.
             pub fn from_item<'a, T>(
                 item: std::collections::HashMap<String, AttributeValue>,
             ) -> Result<T>
@@ -457,11 +257,63 @@ macro_rules! aws_sdk_macro {
                 crate::de::from_item(item)
             }
 
-            /// A version of [`crate::from_items`] where the `Tin` generic is tied to
+            /// A version of [`crate::from_items`] where the `AV` generic is tied to
             /// [`aws-sdk-dynamodb::model::AttributeValue`](AttributeValue).
             ///
             /// Useful in very generic code where the type checker can't determine the type of
-            /// `Tin`.
+            /// `AV`.
+            pub fn from_items<'a, T>(
+                items: Vec<std::collections::HashMap<String, AttributeValue>>,
+            ) -> Result<Vec<T>>
+            where
+                T: serde::de::Deserialize<'a>,
+            {
+                crate::de::from_items(items)
+            }
+        }
+
+        #[cfg(feature = $feature)]
+        #[doc(hidden)]
+        #[deprecated(since = "4.0.0", note = "The double-underscore is no longer necessary")]
+        pub mod $crate_name {
+            use crate::Result;
+            use ::$crate_name::model::AttributeValue;
+
+            #[deprecated(since = "4.0.0", note = "The double-underscore on the mod name is no longer necessary")]
+            pub fn to_attribute_value<T>(value: T) -> Result<AttributeValue>
+            where
+                T: serde::ser::Serialize,
+            {
+                crate::ser::to_attribute_value(value)
+            }
+
+            #[deprecated(since = "4.0.0", note = "The double-underscore on the mod name is no longer necessary")]
+            pub fn to_item<T>(value: T) -> Result<std::collections::HashMap<String, AttributeValue>>
+            where
+                T: serde::ser::Serialize,
+            {
+                crate::ser::to_item(value)
+            }
+
+            #[deprecated(since = "4.0.0", note = "The double-underscore on the mod name is no longer necessary")]
+            pub fn from_attribute_value<'a, T>(attribute_value: AttributeValue) -> Result<T>
+            where
+                T: serde::de::Deserialize<'a>,
+            {
+                crate::de::from_attribute_value(attribute_value)
+            }
+
+            #[deprecated(since = "4.0.0", note = "The double-underscore on the mod name is no longer necessary")]
+            pub fn from_item<'a, T>(
+                item: std::collections::HashMap<String, AttributeValue>,
+            ) -> Result<T>
+            where
+                T: serde::de::Deserialize<'a>,
+            {
+                crate::de::from_item(item)
+            }
+
+            #[deprecated(since = "4.0.0", note = "The double-underscore on the mod name is no longer necessary")]
             pub fn from_items<'a, T>(
                 items: Vec<std::collections::HashMap<String, AttributeValue>>,
             ) -> Result<Vec<T>>
