@@ -1,8 +1,10 @@
+mod aws_lambda_events;
 mod aws_sdk;
 mod aws_sdk_streams;
 mod rusoto;
 mod rusoto_streams;
 
+pub(crate) use aws_lambda_events::aws_lambda_events_macro;
 pub(crate) use aws_sdk::aws_sdk_macro;
 pub(crate) use aws_sdk_streams::aws_sdk_streams_macro;
 pub(crate) use rusoto::rusoto_macro;
