@@ -1,16 +1,17 @@
-use super::{AttributeValue, Error, Item, Result, Serializer};
+use super::{AttributeValue, Error, Result, Serializer};
 use serde::{ser, Serialize};
+use std::collections::HashMap;
 
 pub struct SerializerStructVariant {
     key: &'static str,
-    item: Item,
+    item: HashMap<String, AttributeValue>,
 }
 
 impl SerializerStructVariant {
     pub fn new(key: &'static str, len: usize) -> Self {
         Self {
             key,
-            item: Item::with_capacity(len),
+            item: HashMap::with_capacity(len),
         }
     }
 }
@@ -19,33 +20,24 @@ impl<'a> ser::SerializeStructVariant for SerializerStructVariant {
     type Ok = AttributeValue;
     type Error = Error;
 
-    fn serialize_field<T: ?Sized>(
+    fn serialize_field<F: ?Sized>(
         &mut self,
         key: &'static str,
-        value: &T,
+        value: &F,
     ) -> Result<(), Self::Error>
     where
-        T: Serialize,
+        F: Serialize,
     {
-        let serializer = Serializer;
+        let serializer = Serializer::default();
         let value = value.serialize(serializer)?;
         self.item.insert(key.to_string(), value);
         Ok(())
     }
 
     fn end(self) -> Result<Self::Ok, Self::Error> {
-        let mut hashmap = Item::with_capacity(1);
-        hashmap.insert(
-            self.key.to_string(),
-            AttributeValue {
-                m: Some(self.item),
-                ..AttributeValue::default()
-            },
-        );
+        let mut hashmap = HashMap::with_capacity(1);
+        hashmap.insert(self.key.to_string(), AttributeValue::M(self.item));
 
-        Ok(AttributeValue {
-            m: Some(hashmap),
-            ..AttributeValue::default()
-        })
+        Ok(AttributeValue::M(hashmap))
     }
 }
